==> insuideindoor-1.1.27.tar.gz: lib/main/splash.dart <==
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:insuideindoor/main/MyHome.dart';
import 'package:insuideindoor/main/main.dart';
import 'package:location/location.dart';
import 'package:mapbox_gl/mapbox_gl.dart';
import 'package:shared_preferences/shared_preferences.dart';

late SharedPreferences sharedPreferences;

LatLng GetLatLngFromSP() {
  return LatLng(sharedPreferences.getDouble('latitude')!,
      sharedPreferences.getDouble('longitude')!);
}

class Splash extends StatefulWidget {
  const Splash({Key? key}) : super(key: key);

  @override
  State<Splash> createState() => _SplashState();
}

class _SplashState extends State<Splash> {
  // bool isLoadingIA = true;
  LatLng? IAcoordinates;
  @override
  void initState() {
    super.initState();
    loadSharedPref();
    // initializeLocationAndSave();
    // fetchCurrentLocationViaIA();
  }

  navigateMe() {
    Navigator.push(
      context,
      MaterialPageRoute(
          builder: (context) =>
              const MyHome(data: "26.828943333333335,75.80561666666667")),
    );
  }

  loadSharedPref() async {
    sharedPreferences = await SharedPreferences.getInstance();
  }

  // fetchCurrentLocationViaIA() {
  //   const Channel = MethodChannel("com.mapbox.mapboxglexample");
  //   const platform = const MethodChannel("com.mapbox.mapboxglexample");

  //   platform.setMethodCallHandler((call) async {
  //     print("init state setMethodCallHandler ${call.arguments}");

  //     Navigator.pushAndRemoveUntil(
  //         context,
  //         // MaterialPageRoute(builder: (_) => MyHome(data: call.arguments)),
  //         MaterialPageRoute(
  //             builder: (_) =>
  //                 const MyHome(data: "26.828943333333335,75.80561666666667")),
  //         // Home2()),
  //         (route) => false);
  //   });
  // }

  // void initializeLocationAndSave() async {
  //   // Ensure all permissions are collected for Locations
  //   Location location = Location();
  //   bool serviceEnabled;
  //   PermissionStatus? permissionGranted;

  //   serviceEnabled = await location.serviceEnabled();
  //   if (!serviceEnabled) {
  //     serviceEnabled = await location.requestService();
  //   }

  //   permissionGranted = await location.hasPermission();
  //   if (permissionGranted == PermissionStatus.denied) {
  //     permissionGranted = await location.requestPermission();
  //   }

  //   // Get the current user location
  //   LocationData _locationData = await location.getLocation();
  //   LatLng currentLocation =
  //       LatLng(_locationData.latitude!, _locationData.longitude!);

  //   // Get the current user address
  //   // String currentAddress =
  //   //     (await getParsedReverseGeocoding(currentLocation))['place'];

  //   // Store the user location in sharedPreferences
  //   sharedPreferences.setDouble('latitude', _locationData.latitude!);
  //   sharedPreferences.setDouble('longitude', _locationData.longitude!);

  //   // sharedPreferences.setString('current-address', currentAddress);

  //   // ignore: use_build_context_synchronously
  // }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Center(child: CircularProgressIndicator()),
          SizedBox(height: 20),
          Text("Fetching Location Details"),
          ElevatedButton(
              onPressed: () {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                      builder: (context) => const MyHome(
                          data: "26.828943333333335,75.80561666666667")),
                );
              },
              child: const Text("Next"))
        ],
      ),
    );
  }
}

==> insuideindoor-1.1.28.tar.gz: lib/main/splash.dart <==
import 'package:flutter/services.dart';
import 'package:flutter/material.dart';
import 'package:insuideindoor/main/MyHome.dart';
import 'package:insuideindoor/main/main.dart';
import 'package:location/location.dart';
import 'package:mapbox_gl/mapbox_gl.dart';
import 'package:shared_preferences/shared_preferences.dart';

late SharedPreferences sharedPreferences;

LatLng GetLatLngFromSP() {
  return LatLng(sharedPreferences.getDouble('latitude')!,
      sharedPreferences.getDouble('longitude')!);
}

class Splash extends StatefulWidget {
  const Splash({Key? key}) : super(key: key);

  @override
  State<Splash> createState() => _SplashState();
}

class _SplashState extends State<Splash> {
  // bool isLoadingIA = true;
  LatLng? IAcoordinates;
  @override
  void initState() {
    super.initState();
    loadSharedPref();
    // initializeLocationAndSave();
    // fetchCurrentLocationViaIA();
  }

  navigateMe() {
    Navigator.push(
      context,
      MaterialPageRoute(
          builder: (context) =>
              const MyHome(data: "26.828943333333335,75.80561666666667")),
    );
  }

  loadSharedPref() async {
    sharedPreferences = await SharedPreferences.getInstance();
  }

  // fetchCurrentLocationViaIA() {
  //   const Channel = MethodChannel("com.mapbox.mapboxglexample");
  //   const platform = const MethodChannel("com.mapbox.mapboxglexample");

  //   platform.setMethodCallHandler((call) async {
  //     print("init state setMethodCallHandler ${call.arguments}");

  //     Navigator.pushAndRemoveUntil(
  //         context,
  //         // MaterialPageRoute(builder: (_) => MyHome(data: call.arguments)),
  //         MaterialPageRoute(
  //             builder: (_) =>
  //                 const MyHome(data: "26.828943333333335,75.80561666666667")),
  //         // Home2()),
  //         (route) => false);
  //   });
  // }

  // void initializeLocationAndSave() async {
  //   // Ensure all permissions are collected for Locations
  //   Location location = Location();
  //   bool serviceEnabled;
  //   PermissionStatus? permissionGranted;

  //   serviceEnabled = await location.serviceEnabled();
  //   if (!serviceEnabled) {
  //     serviceEnabled = await location.requestService();
  //   }

  //   permissionGranted = await location.hasPermission();
  //   if (permissionGranted == PermissionStatus.denied) {
  //     permissionGranted = await location.requestPermission();
  //   }

  //   // Get the current user location
  //   LocationData _locationData = await location.getLocation();
  //   LatLng currentLocation =
  //       LatLng(_locationData.latitude!, _locationData.longitude!);

  //   // Get the current user address
  //   // String currentAddress =
  //   //     (await getParsedReverseGeocoding(currentLocation))['place'];

  //   // Store the user location in sharedPreferences
  //   sharedPreferences.setDouble('latitude', _locationData.latitude!);
  //   sharedPreferences.setDouble('longitude', _locationData.longitude!);

  //   // sharedPreferences.setString('current-address', currentAddress);

  //   // ignore: use_build_context_synchronously
  // }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          const Center(child: CircularProgressIndicator()),
          const SizedBox(height: 20),
          const Text("Fetching Location Details"),
          ElevatedButton(
              onPressed: () {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                      builder: (context) => const MyHome(
                          data: "26.828943333333335,75.80561666666667")),
                );
              },
              child: const Text("Next"))
        ],
      ),
    );
  }
}
